package auctionsim

import (
	"math"
	"math/rand"
)

/**
 * NormalestDistribution returns a NormalDistribution with a new rand.Rand
 * behind it (randomly seeded), with standard deviation of 1 and mean of 0.
 */
func NormalestDistribution() *NormalDistribution {
	return &NormalDistribution{
		Rand:   rand.New(rand.NewSource(int64(rand.Uint64()))),
		StdDev: 1,
		Mean:   0,
	}
}

/**
 * NormalestBidderGenerator returns a BidderGenerator that returns an infinite
 * number of Bidders with infinite cash, and values and errors normally
 * distributed around 0.
 */
func NormalestBidderGenerator() BidderGenerator {
	d := NormalestDistribution()
	return &BiddersFromDistributions{
		Values:          d,
		Irrationalities: d,
		Bankrolls:       ConstDistribution(math.Inf(1)),
	}
}
